==> universally-3.0.0.tar.gz: lib/component/src/widgets.dart <==
import 'package:flutter/material.dart';
import 'package:universally/universally.dart';

class BottomPadding extends Universal {
  BottomPadding(
      {super.key,
      double left = 20,
      double top = 10,
      double right = 20,
      double bottom = 10,
      super.child,
      super.color})
      : super(
            padding: EdgeInsets.fromLTRB(
                left, top, right, getBottomNavigationBarHeight + bottom));
}

class CustomDivider extends Divider {
  const CustomDivider(
      {super.color = UCS.background,
      super.key,
      super.endIndent,
      super.indent,
      super.thickness,
      super.height = 1});
}

extension ExtensionNotificationListener on Widget {
  Widget interceptNotificationListener<T extends Notification>(
          {NotificationListenerCallback<T>? onNotification}) =>
      NotificationListener<T>(
          onNotification: (T notification) {
            if (onNotification != null) onNotification(notification);
            return true;
          },
          child: this);
}

/// 局部 异步加载数据
class BasicFutureBuilder<T> extends CustomFutureBuilder<T> {
  BasicFutureBuilder({
    super.key,
    super.initialData,
    required super.future,
    required super.onDone,
    CustomFutureBuilderNone? onNone,
  }) : super(
            onNone:
                onNone ?? (_, __) => const Center(child: BasicPlaceholder()),
            onWaiting: (_) => const Center(child: BasicLoading()),
            onError: (_, __, reset) => BasicError(onTap: reset));
}

/// 局部 异步加载数据
class BasicStreamBuilder<T> extends CustomStreamBuilder<T> {
  BasicStreamBuilder({
    super.key,
    super.initialData,
    required super.stream,
    required super.onDone,
    CustomBuilderContext? onNone,
  }) : super(
            onNone: onNone ?? (_) => const Center(child: BasicPlaceholder()),
            onWaiting: (_) => const Center(child: BasicLoading()),
            onError: (_, __) => const BasicError());
}

class BasicError extends StatelessWidget {
  const BasicError({super.key, this.onTap});

  final GestureTapCallback? onTap;

  @override
  Widget build(BuildContext context) {
    return Universal(alignment: Alignment.center, onTap: onTap, children: [
      SVGAsset(UAS.noDataIcon, height: 90, package: 'universally'),
      const SizedBox(height: 10),
      TextDefault('加载失败，点击刷新', fontSize: 13)
    ]);
  }
}

class BasicSwitch extends SwitchState {
  BasicSwitch({
    super.key,
    required super.value,
    Color? activeColor,
    super.activeTrackColor,
    super.onChanged,
    super.onWaitChanged,
  }) : super.adaptive(activeColor: activeColor ?? GlobalConfig().currentColor);
}

class BasicCupertinoSwitch extends CupertinoSwitchState {
  BasicCupertinoSwitch({
    super.key,
    required super.value,
    Color? activeColor,
    super.trackColor,
    super.thumbColor,
    super.onChanged,
    super.onWaitChanged,
  }) : super(activeColor: activeColor ?? GlobalConfig().currentColor);
}

class BasicCheckbox extends CheckboxState {
  BasicCheckbox({
    super.key,
    required super.value,
    Color? activeColor,
    super.onChanged,
    super.onWaitChanged,
  }) : super(activeColor: activeColor ?? GlobalConfig().currentColor);
}

class UButton extends SimpleButton {
  UButton({
    super.key,
    super.color,
    required super.text,
    super.textStyle = const TStyle(color: UCS.white),
    super.margin,
    super.width = UConstant.longWidth,
    super.height = 45,
    bool enabled = true,
    super.visible = true,
    super.child,
    GestureTapCallback? onTap,
    super.isElastic = true,
    super.alignment = Alignment.center,
  }) : super(
            heroTag: text,
            onTap: enabled ? onTap : null,
            decoration: BoxDecoration(
                border: Border.all(color: GlobalConfig().currentColor),
                color: color ?? GlobalConfig().currentColor,
                borderRadius: BorderRadius.circular(8)));
}

class USpacing extends StatelessWidget {
  const USpacing(
      {super.key,
      this.spacing = 6,
      this.horizontal = false,
      this.color,
      this.height,
      this.width});

  final double? spacing;
  final bool horizontal;
  final Color? color;
  final double? height;
  final double? width;

  @override
  Widget build(BuildContext context) => Container(
      color: color,
      height: height ?? (horizontal ? 0 : spacing),
      width: width ?? (horizontal ? spacing : 0));
}

==> universally-3.2.0.tar.gz: lib/component/src/widgets.dart <==
import 'package:flutter/material.dart';
import 'package:universally/universally.dart';

class BottomPadding extends Universal {
  BottomPadding(
      {super.key,
      double left = 20,
      double top = 10,
      double right = 20,
      double bottom = 10,
      super.child,
      super.color})
      : super(
            padding: EdgeInsets.fromLTRB(
                left, top, right, getBottomNavigationBarHeight + bottom));
}

class CustomDivider extends Divider {
  const CustomDivider(
      {super.color = UCS.background,
      super.key,
      super.endIndent,
      super.indent,
      super.thickness,
      super.height = 1});
}

extension ExtensionNotificationListener on Widget {
  Widget interceptNotificationListener<T extends Notification>(
          {NotificationListenerCallback<T>? onNotification}) =>
      NotificationListener<T>(
          onNotification: (T notification) {
            if (onNotification != null) onNotification(notification);
            return true;
          },
          child: this);
}

/// 局部 异步加载数据
class BasicFutureBuilder<T> extends CustomFutureBuilder<T> {
  BasicFutureBuilder({
    super.key,
    super.initialData,
    required super.future,
    required super.onDone,
    CustomFutureBuilderNone? onNone,
  }) : super(
            onNone:
                onNone ?? (_, __) => const Center(child: BasicPlaceholder()),
            onWaiting: (_) => const Center(child: BasicLoading()),
            onError: (_, __, reset) => BasicError(onTap: reset));
}

/// 局部 异步加载数据
class BasicStreamBuilder<T> extends CustomStreamBuilder<T> {
  BasicStreamBuilder({
    super.key,
    super.initialData,
    required super.stream,
    required super.onDone,
    CustomBuilderContext? onNone,
  }) : super(
            onNone: onNone ?? (_) => const Center(child: BasicPlaceholder()),
            onWaiting: (_) => const Center(child: BasicLoading()),
            onError: (_, __) => const BasicError());
}

class BasicError extends StatelessWidget {
  const BasicError({super.key, this.onTap});

  final GestureTapCallback? onTap;

  @override
  Widget build(BuildContext context) {
    return Universal(alignment: Alignment.center, onTap: onTap, children: [
      SVGAsset(UAS.noDataIcon, height: 90, package: 'universally'),
      const SizedBox(height: 10),
      TextDefault('加载失败，点击刷新', fontSize: 13)
    ]);
  }
}

class BasicSwitch extends SwitchState {
  BasicSwitch({
    super.key,
    required super.value,
    Color? activeColor,
    super.activeTrackColor,
    super.onChanged,
    super.onWaitChanged,
  }) : super.adaptive(activeColor: activeColor ?? GlobalConfig().currentColor);
}

class BasicCupertinoSwitch extends CupertinoSwitchState {
  BasicCupertinoSwitch({
    super.key,
    required super.value,
    Color? activeColor,
    super.trackColor,
    super.thumbColor,
    super.onChanged,
    super.onWaitChanged,
  }) : super(activeColor: activeColor ?? GlobalConfig().currentColor);
}

class BasicCheckbox extends CheckboxState {
  BasicCheckbox({
    super.key,
    required super.value,
    Color? activeColor,
    super.onChanged,
    super.onWaitChanged,
  }) : super(activeColor: activeColor ?? GlobalConfig().currentColor);
}

class UButton extends SimpleButton {
  UButton({
    super.key,
    super.color,
    required super.text,
    super.textStyle = const TStyle(color: UCS.white),
    super.margin,
    super.width = UConst.longWidth,
    super.height = 45,
    bool enabled = true,
    super.visible = true,
    super.child,
    GestureTapCallback? onTap,
    super.isElastic = true,
    super.alignment = Alignment.center,
  }) : super(
            heroTag: text,
            onTap: enabled ? onTap : null,
            decoration: BoxDecoration(
                border: Border.all(color: GlobalConfig().currentColor),
                color: color ?? GlobalConfig().currentColor,
                borderRadius: BorderRadius.circular(8)));
}

class USpacing extends StatelessWidget {
  const USpacing(
      {super.key,
      this.spacing = 6,
      this.horizontal = false,
      this.color,
      this.height,
      this.width});

  final double? spacing;
  final bool horizontal;
  final Color? color;
  final double? height;
  final double? width;

  @override
  Widget build(BuildContext context) => Container(
      color: color,
      height: height ?? (horizontal ? 0 : spacing),
      width: width ?? (horizontal ? spacing : 0));
}
